@@ -16,7 +16,7 @@
 __author__ = "Anton Panasenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.18"
+__version__ = "1.0.19"
 __email__ = "apanasenko@qubell.com"
 
 import unittest
@@ -278,7 +278,7 @@ class SandBox(object):
                 self.__cloud_account(environment, provider)
 
             for police in env.get('policies', []):
-                environment.policyAdd(police)
+                environment.add_policy(police)
 
             for app in self.sandbox["applications"]:
                 self.__application(app)
